#!/bin/bash

# The converter is expected to accept the full file name of the image or video to convert as a parameter. It
# must return the full name (including path) of the generated preview via its standard out channel.
# Preview generators must not create other output on the standard out or standard error channel. 
#

# DEBUG must be used only when running the script in a shell 
# for testing, P5 does not support this option 
#DEBUG="1"
DEBUG=""

AW_PATH="/usr/local/aw/bin"
if [ ! -z "$AWPST_SRV_HOME" ]
then 
	[ $DEBUG ] && echo "AWPST_SRV_HOME is defined and has the value > $AWPST_SRV_HOME <"
	AW_PATH="$AWPST_SRV_HOME"/bin
else 
        [ $DEBUG ] && echo "[-] AWPST_SRV_HOME is NOT defined "
fi
[ $DEBUG ] && echo "AW_PATH = $AW_PATH"

FFMPEG="$AW_PATH/ffmpeg"
FFPROBE="$AW_PATH/ffprobe"
TMP="/tmp"

if [ "$1" == -v ] 
then
	input_file=$2
	DEBUG=1
else
	input_file=$1
fi

if [ ! -f "$input_file" ]
then
	[ $DEBUG == "1" ] && echo "[-] File $input_file not found"
	exit 1 
fi

# seek position="00:00:10" 
position="10"

# mosaic is format 4:3
mosaic_factor=1
# a 1 value ratio 4x3=	12 images
# a 2 value ratio 8x6=	48 images
# a 3 value ratio 12x9= 108 images ...

# find tiling
tiling_value=$(( 4 * $mosaic_factor))x$((3 * $mosaic_factor))
[ $DEBUG ] && echo "Tiles = $tiling_value"

nb_frames_to_extract=$(( $mosaic_factor*4 * $mosaic_factor*3 ))
[ $DEBUG ] && echo "Frames number = $nb_frames_to_extract"

nb_total_frames=$($FFPROBE -v error -of flat=s=_ -select_streams v:0 -show_entries stream=nb_frames "$input_file" | cut -d'=' -f2 )
nb_total_frames=`echo $nb_total_frames | tr -d \"  `
[ $DEBUG ] && echo "Total number of frames = $nb_total_frames"

# interval between 2 frames 
int_frame=$(( $nb_total_frames / $nb_frames_to_extract ))
[ $DEBUG ] && echo "Frames interval = $int_frame"

# 
#  output filename generation as jpg 
filename=$(basename -- "$input_file")
filename="${filename%.*}"
output_file=$TMP/$filename.jpg
ffmpeg_output=$TMP/$filename.log

quiet_option="-hide_banner -loglevel error"
[ $DEBUG ] && quiet_option=""

$FFMPEG \
			$quiet_option \
			-ss "$position" \
			-i "$input_file" \
			-frames 1 \
			-filter:v "select=not(mod(n\,$int_frame)),scale=320:240,tile=$tiling_value" \
			-y	\
			"$output_file" 2> "$ffmpeg_output"


[ $DEBUG ] && cat "$ffmpeg_output"


echo $output_file

